# _data_utils_
- **preprocessing**
> _class_ **Processer**
>> **nothing**
>> 

- **analysis**
- **processing**
- **collection**
- **preparation**

------------------------

# _model_utils_
- **preprocessing**
> _class_ **Processer**
>> **nothing**
>>
- 模型（模型改进版，训练，预测，评估）

-------------------------

# _api_utils_
- **preprocessing**
> _class_ **Processer**
>> **nothing**
>>
- 模型（模型改进版，训练，预测，评估）

- ap
部署（前端，后台，接口）
- utils
其他（常用算法，常用方法,测试）
